This function allows you to run the IRT model.
M_constrained_irt(
Y,
d,
M = NULL,
theta_fix = NULL,
which_fix = NULL,
nburn = 1000,
nsamp = 1000,
thin = 10,
learn_Sigma = TRUE,
learn_Omega = FALSE,
hyperparameters = list(),
display_progress = TRUE
)A list containing the following components:
An array of dimension (K x d x nsamp/thin) containing posterior samples of item discrimination parameters.
A matrix of dimension (K x nsamp/thin) containing posterior samples of item difficulty parameters.
An array of dimension (N x d x nsamp/thin) containing posterior samples of respondent latent trait values.
An array of dimension (d x d x nsamp/thin) containing posterior samples of the covariance matrix of latent traits (only if learn_Sigma=TRUE).
An array of dimension (d x d x nsamp/thin) containing posterior samples of the covariance matrix of item loadings (only if learn_Omega=TRUE).
a N x K matrix of responses given by N respondents to K items. Can contain missing values.
an integer specifying the number of latent dimensions.
a list of K d x d matrices (default=NULL).
a matrix with d columns containing the values of the latent dimensions for respondents that have pre-specified latent factors.
a vector containing the indices of the respondents for which latent factors have been fixed.
an integer specifying the number of burn-in MCMC iterations.
an integer specifying the number of sampling MCMC iterations.
an integer specifying the number of thinning MCMC samples.
a Boolean specifying whether a covariance matrix for the latent factors should be learned.
a Boolean specifying whether a covariance matrix for the latent loadings should be learned.
a list of hyperparameters for the model.
a Boolean specifying whether a progress bar should be displayed.