Learn R Programming

IRTM (version 0.0.1.1)

synth_questions: Questions for the Synthetic European sentiment survey in the vignette

Description

A synthetic dataset with 3000 rows and 148 questions. This data replicates the structure of questions following Eurobarometer 94.3 (2021). It is not intended to be analyzed independently from the vignette. '

Arguments

Format

A data frame with 3000 rows and 148 columns representing synthetic survey responses